# Generated by Plain 0.47.0 on 2025-06-06 17:45

from plain import models
from plain.models import migrations


class Migration(migrations.Migration):
    dependencies = [
        (
            "plainpageviews",
            "0005_alter_pageview_session_key_alter_pageview_timestamp_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="pageview",
            name="referrer",
            field=models.CharField(max_length=1024, required=False),
        ),
    ]
