# Generated by Plain 0.15.0 on 2025-01-06 20:20

import uuid

from plain import models
from plain.models import migrations


class Migration(migrations.Migration):
    dependencies = [
        (
            "plainpageviews",
            "0002_alter_pageview_referrer_alter_pageview_title_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="pageview",
            name="uuid",
            field=models.UUIDField(default=uuid.uuid4),
        ),
    ]
